@@ -1,13 +1,11 @@
 import importlib
-from .engine import Engine
 from .support import DBError
 from .log_support import logger
 from .constant import DRIVERS, UNKNOW
 
 
-def import_driver(driver):
+def import_driver(driver, curr_engine):
     creator = None
-    curr_engine = Engine.current_engine()
     if driver:
         if driver not in DRIVERS:
             logger.warning(f"Driver '{driver}' not support now, may be you should adapte it youself.")
